@@ -142,7 +142,10 @@ class Resource(Generic[D]):
         """
         Retrieve this resource's (specification-specific) identifier.
         """
-        return self._specification.id_of(self.contents)
+        id = self._specification.id_of(self.contents)
+        if id is None:
+            return
+        return id.rstrip("#")
 
     def subresources(self) -> Iterable[Resource[D]]:
         """
@@ -362,7 +365,9 @@ class Registry(Mapping[URI, Resource[D]]):
         """
         Retrieve the contents identified by the given URI.
         """
-        return self._resources[uri].contents
+        # Empty fragment URIs are equivalent to URIs without the fragment.
+        # TODO: Is this true for non JSON Schema resources? Probably not.
+        return self._resources[uri.rstrip("#")].contents
 
     def crawl(self) -> Registry[D]:
         """
