@@ -155,6 +155,12 @@ class TestRegistry:
         registry = Registry().with_resource(uri, resource)
         assert registry.contents(uri) == {"foo": "bar"}
 
+    def test_contents_strips_empty_fragments(self):
+        uri = "http://example.com/"
+        resource = ID_AND_CHILDREN.create_resource({"ID": uri + "#"})
+        registry = resource @ Registry()
+        assert registry.contents(uri) == {"ID": uri + "#"}
+
     def test_crawled_anchor(self):
         resource = ID_AND_CHILDREN.create_resource({"anchors": {"foo": "bar"}})
         registry = Registry().with_resource("urn:example", resource)
@@ -604,6 +610,11 @@ class TestResource:
         )
         assert resource.id() == "urn:fixedID"
 
+    def test_id_strips_empty_fragment(self):
+        uri = "http://example.com/"
+        root = ID_AND_CHILDREN.create_resource({"ID": uri + "#"})
+        assert root.id() == uri
+
     def test_subresources_delegates_to_specification(self):
         resource = ID_AND_CHILDREN.create_resource({"children": [{}, 12]})
         assert list(resource.subresources()) == [
